@@ -1,6 +1,217 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="he_IL">
+<context>
+    <name>MainWindow</name>
+    <message>
+        <location filename="../mainwindow.ui" line="14"/>
+        <source>MX Codecs Installer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="27"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some juridictions their distribution may be limited so the user must meet local regulations. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="44"/>
+        <source>Downloading codecs files</source>
+        <translation type="unfinished">מוריד קבצי קודקים</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="94"/>
+        <source>Cancel any changes then quit</source>
+        <translation type="unfinished">בטל את כל השינויים ואז צא</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="97"/>
+        <location filename="../mainwindow.cpp" line="268"/>
+        <source>Cancel</source>
+        <translation type="unfinished">ביטול</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="104"/>
+        <source>Alt+N</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="117"/>
+        <source>Apply any changes then quit</source>
+        <translation type="unfinished">אשר את כל השינויים ואז צא</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="120"/>
+        <source>OK</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="175"/>
+        <source>About this application</source>
+        <translation type="unfinished">מידע לגבי התוכנה הזו</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="178"/>
+        <source>About...</source>
+        <translation type="unfinished">אודות...</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="185"/>
+        <source>Alt+B</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="214"/>
+        <source>Display help </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="217"/>
+        <source>Help</source>
+        <translation type="unfinished">עזרה</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="224"/>
+        <source>Alt+H</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="105"/>
+        <location filename="../mainwindow.cpp" line="112"/>
+        <location filename="../mainwindow.cpp" line="120"/>
+        <location filename="../mainwindow.cpp" line="128"/>
+        <location filename="../mainwindow.cpp" line="137"/>
+        <location filename="../mainwindow.cpp" line="144"/>
+        <location filename="../mainwindow.cpp" line="153"/>
+        <location filename="../mainwindow.cpp" line="161"/>
+        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="108"/>
+        <location filename="../mainwindow.cpp" line="124"/>
+        <location filename="../mainwindow.cpp" line="131"/>
+        <location filename="../mainwindow.cpp" line="140"/>
+        <location filename="../mainwindow.cpp" line="146"/>
+        <location filename="../mainwindow.cpp" line="157"/>
+        <location filename="../mainwindow.cpp" line="164"/>
+        <location filename="../mainwindow.cpp" line="193"/>
+        <location filename="../mainwindow.cpp" line="246"/>
+        <source>Error</source>
+        <translation type="unfinished">תקלה</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="109"/>
+        <location filename="../mainwindow.cpp" line="125"/>
+        <location filename="../mainwindow.cpp" line="141"/>
+        <location filename="../mainwindow.cpp" line="158"/>
+        <source>Cannot connect to the download site</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="115"/>
+        <location filename="../mainwindow.cpp" line="132"/>
+        <location filename="../mainwindow.cpp" line="147"/>
+        <location filename="../mainwindow.cpp" line="165"/>
+        <source>Error downloading %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="170"/>
+        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="189"/>
+        <source>Installing downloaded files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="194"/>
+        <source>No downloaded *.debs files found.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="207"/>
+        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="220"/>
+        <source>Error installing %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="224"/>
+        <source>Fix missing dependencies...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="226"/>
+        <source>Error running %1 command</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="238"/>
+        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="242"/>
+        <source>Finished</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="243"/>
+        <source>Codecs files have been downloaded and installed successfully.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="247"/>
+        <source>Process finished. Errors have occurred during the installation.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="261"/>
+        <source>About MX Codecs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="262"/>
+        <source>MX Codecs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="262"/>
+        <source>Version: </source>
+        <translation type="unfinished">גרסה:</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="264"/>
+        <source>Simple codecs downloader for MX Linux</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="265"/>
+        <source>Copyright (c) MX Linux</source>
+        <translation type="unfinished">זכויות שמורות MX Linux</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="266"/>
+        <source>License</source>
+        <translation type="unfinished">רשיון</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="267"/>
+        <location filename="../mainwindow.cpp" line="277"/>
+        <source>Changelog</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="285"/>
+        <source>&amp;Close</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>QApplication</name>
     <message>
@@ -20,214 +231,50 @@
     </message>
 </context>
 <context>
-    <name>mxcodecs</name>
+    <name>mainwindow</name>
     <message>
-        <location filename="../mxcodecs.ui" line="14"/>
-        <source>MX Codecs Installer</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.ui" line="27"/>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;justify&quot;&gt;This application allows you to install restricted codecs that permit advanced video and audio functions.&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;In some juridictions their distribution may be limited so the user must meet local regulations. &lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;br/&gt;&lt;/p&gt;&lt;p align=&quot;justify&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Do you assume legal responsibility for downloading these codecs?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.ui" line="44"/>
         <source>Downloading codecs files</source>
-        <translation>מוריד קבצי קודקים</translation>
+        <translation type="vanished">מוריד קבצי קודקים</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.ui" line="94"/>
         <source>Cancel any changes then quit</source>
-        <translation>בטל את כל השינויים ואז צא</translation>
+        <translation type="vanished">בטל את כל השינויים ואז צא</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.ui" line="97"/>
-        <location filename="../mxcodecs.cpp" line="267"/>
         <source>Cancel</source>
-        <translation>ביטול</translation>
+        <translation type="vanished">ביטול</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.ui" line="105"/>
-        <source>Alt+N</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.ui" line="118"/>
         <source>Apply any changes then quit</source>
-        <translation>אשר את כל השינויים ואז צא</translation>
+        <translation type="vanished">אשר את כל השינויים ואז צא</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.ui" line="121"/>
-        <source>OK</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.ui" line="177"/>
         <source>About this application</source>
-        <translation>מידע לגבי התוכנה הזו</translation>
+        <translation type="vanished">מידע לגבי התוכנה הזו</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.ui" line="180"/>
         <source>About...</source>
-        <translation>אודות...</translation>
+        <translation type="vanished">אודות...</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.ui" line="188"/>
-        <source>Alt+B</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.ui" line="217"/>
-        <source>Display help </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.ui" line="220"/>
         <source>Help</source>
-        <translation>עזרה</translation>
+        <translation type="vanished">עזרה</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.ui" line="228"/>
-        <source>Alt+H</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="104"/>
-        <location filename="../mxcodecs.cpp" line="111"/>
-        <location filename="../mxcodecs.cpp" line="119"/>
-        <location filename="../mxcodecs.cpp" line="127"/>
-        <location filename="../mxcodecs.cpp" line="136"/>
-        <location filename="../mxcodecs.cpp" line="143"/>
-        <location filename="../mxcodecs.cpp" line="152"/>
-        <location filename="../mxcodecs.cpp" line="160"/>
-        <source>&lt;b&gt;Running command...&lt;/b&gt;&lt;p&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="107"/>
-        <location filename="../mxcodecs.cpp" line="123"/>
-        <location filename="../mxcodecs.cpp" line="130"/>
-        <location filename="../mxcodecs.cpp" line="139"/>
-        <location filename="../mxcodecs.cpp" line="145"/>
-        <location filename="../mxcodecs.cpp" line="156"/>
-        <location filename="../mxcodecs.cpp" line="163"/>
-        <location filename="../mxcodecs.cpp" line="192"/>
-        <location filename="../mxcodecs.cpp" line="245"/>
         <source>Error</source>
-        <translation>תקלה</translation>
+        <translation type="vanished">תקלה</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="108"/>
-        <location filename="../mxcodecs.cpp" line="124"/>
-        <location filename="../mxcodecs.cpp" line="140"/>
-        <location filename="../mxcodecs.cpp" line="157"/>
-        <source>Cannot connect to the download site</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="114"/>
-        <location filename="../mxcodecs.cpp" line="131"/>
-        <location filename="../mxcodecs.cpp" line="146"/>
-        <location filename="../mxcodecs.cpp" line="164"/>
-        <source>Error downloading %1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="169"/>
-        <source>&lt;b&gt;Download Finished.&lt;/b&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="188"/>
-        <source>Installing downloaded files</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="193"/>
-        <source>No downloaded *.debs files found.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="206"/>
-        <source>&lt;b&gt;Installing...&lt;/b&gt;&lt;p&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="219"/>
-        <source>Error installing %1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="223"/>
-        <source>Fix missing dependencies...</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="225"/>
-        <source>Error running %1 command</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="237"/>
-        <source>&lt;b&gt;Installation process has finished&lt;/b&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="241"/>
-        <source>Finished</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="242"/>
-        <source>Codecs files have been downloaded and installed successfully.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="246"/>
-        <source>Process finished. Errors have occurred during the installation.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="260"/>
-        <source>About MX Codecs</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="261"/>
-        <source>MX Codecs</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="261"/>
         <source>Version: </source>
-        <translation>גרסה:</translation>
+        <translation type="vanished">גרסה:</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="263"/>
-        <source>Simple codecs downloader for MX Linux</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="264"/>
         <source>Copyright (c) MX Linux</source>
-        <translation>זכויות שמורות MX Linux</translation>
+        <translation type="vanished">זכויות שמורות MX Linux</translation>
     </message>
     <message>
-        <location filename="../mxcodecs.cpp" line="265"/>
         <source>License</source>
-        <translation>רשיון</translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="266"/>
-        <location filename="../mxcodecs.cpp" line="276"/>
-        <source>Changelog</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mxcodecs.cpp" line="283"/>
-        <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
+        <translation type="vanished">רשיון</translation>
     </message>
 </context>
 </TS>
